@@ -6,23 +6,25 @@
 */
 
 #include "jobtrackermodeltest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "jobtracker.h"
 #include "jobtrackermodel.h"
 // #include "modeltest.h"
 #include <QSignalSpy>
 #include <QTest>
-#include <akonadi/private/instance_p.h>
+#include <private/instance_p.h>
 
 static QString rowSpyToText(const QSignalSpy &spy)
 {
     if (!spy.isValid()) {
-        return QStringLiteral("THE SIGNALSPY IS INVALID!");
+        return u"THE SIGNALSPY IS INVALID!"_s;
     }
     QString str;
     for (int i = 0; i < spy.count(); ++i) {
-        str += spy.at(i).at(1).toString() + QLatin1Char(',') + spy.at(i).at(2).toString();
+        str += spy.at(i).at(1).toString() + u',' + spy.at(i).at(2).toString();
         if (i + 1 < spy.count()) {
-            str += QLatin1Char(';');
+            str += u';';
         }
     }
     return str;
@@ -38,7 +40,7 @@ JobTrackerModelTest::~JobTrackerModelTest() = default;
 void JobTrackerModelTest::initTestCase()
 {
     // Don't interfere with a running akonadiconsole
-    Akonadi::Instance::setIdentifier(QStringLiteral("jobtrackertest"));
+    Akonadi::Instance::setIdentifier(u"jobtrackertest"_s);
 }
 
 void JobTrackerModelTest::shouldBeEmpty()
@@ -53,7 +55,7 @@ void JobTrackerModelTest::shouldDisplayOneJob()
     // GIVEN
     JobTrackerModel model("jobtracker");
     // ModelTest modelTest(&model);
-    const QString jobName(QStringLiteral("job1"));
+    const QString jobName(u"job1"_s);
     QSignalSpy rowATBISpy(&model, &QAbstractItemModel::rowsAboutToBeInserted);
     QSignalSpy rowInsertedSpy(&model, &QAbstractItemModel::rowsInserted);
     connect(&model, &QAbstractItemModel::rowsAboutToBeInserted, this, [&](const QModelIndex &parent) {
@@ -74,29 +76,29 @@ void JobTrackerModelTest::shouldDisplayOneJob()
     });
 
     // WHEN
-    model.jobTracker().jobCreated(QStringLiteral("session1"), jobName, QString(), QStringLiteral("type1"), QStringLiteral("debugStr1"));
+    model.jobTracker().jobCreated(u"session1"_s, jobName, QString(), u"type1"_s, QStringLiteral("debugStr1"));
 
     // THEN
     QCOMPARE(model.rowCount(), 1);
     const QModelIndex sessionIndex = model.index(0, 0);
-    QCOMPARE(sessionIndex.data().toString(), QStringLiteral("session1"));
+    QCOMPARE(sessionIndex.data().toString(), u"session1"_s);
     QCOMPARE(model.rowCount(sessionIndex), 1);
     const QModelIndex sessionCol1Index = model.index(0, 1);
     QVERIFY(sessionCol1Index.isValid());
     QCOMPARE(model.rowCount(sessionCol1Index), 0);
     const QModelIndex jobIndex = model.index(0, 0, sessionIndex);
-    QCOMPARE(jobIndex.data().toString(), QStringLiteral("job1"));
+    QCOMPARE(jobIndex.data().toString(), u"job1"_s);
     QCOMPARE(model.rowCount(jobIndex), 0);
-    QCOMPARE(rowSpyToText(rowATBISpy), QStringLiteral("0,0;0,0"));
-    QCOMPARE(rowSpyToText(rowInsertedSpy), QStringLiteral("0,0;0,0"));
+    QCOMPARE(rowSpyToText(rowATBISpy), u"0,0;0,0"_s);
+    QCOMPARE(rowSpyToText(rowInsertedSpy), u"0,0;0,0"_s);
 }
 
 void JobTrackerModelTest::shouldSignalDataChanges()
 {
     // GIVEN
     JobTrackerModel model("jobtracker");
-    const QString jobName(QStringLiteral("job1"));
-    model.jobTracker().jobCreated(QStringLiteral("session1"), jobName, QString(), QStringLiteral("type1"), QStringLiteral("debugStr1"));
+    const QString jobName(u"job1"_s);
+    model.jobTracker().jobCreated(u"session1"_s, jobName, QString(), u"type1"_s, QStringLiteral("debugStr1"));
     QSignalSpy dataChangedSpy(&model, &JobTrackerModel::dataChanged);
 
     // WHEN
@@ -118,8 +120,8 @@ void JobTrackerModelTest::shouldHandleReset()
 {
     // GIVEN
     JobTrackerModel model("jobtracker");
-    const QString jobName(QStringLiteral("job1"));
-    model.jobTracker().jobCreated(QStringLiteral("session1"), jobName, QString(), QStringLiteral("type1"), QStringLiteral("debugStr1"));
+    const QString jobName(u"job1"_s);
+    model.jobTracker().jobCreated(u"session1"_s, jobName, QString(), u"type1"_s, QStringLiteral("debugStr1"));
     QSignalSpy modelATBResetSpy(&model, &JobTrackerModel::modelAboutToBeReset);
     QSignalSpy modelResetSpy(&model, &JobTrackerModel::modelReset);
     QSignalSpy dataChangedSpy(&model, &JobTrackerModel::dataChanged);
@@ -142,8 +144,8 @@ void JobTrackerModelTest::shouldHandleDuplicateJob()
 {
     // GIVEN
     JobTrackerModel model("jobtracker");
-    const QString jobName(QStringLiteral("job1"));
-    model.jobTracker().jobCreated(QStringLiteral("session1"), jobName, QString(), QStringLiteral("type1"), QStringLiteral("debugStr1"));
+    const QString jobName(u"job1"_s);
+    model.jobTracker().jobCreated(u"session1"_s, jobName, QString(), u"type1"_s, QStringLiteral("debugStr1"));
     model.jobTracker().jobStarted(jobName);
     model.jobTracker().jobEnded(jobName, QString());
     model.jobTracker().signalUpdates();
@@ -151,23 +153,23 @@ void JobTrackerModelTest::shouldHandleDuplicateJob()
     // WHEN
     QSignalSpy rowATBISpy(&model, &QAbstractItemModel::rowsAboutToBeInserted);
     QSignalSpy rowInsertedSpy(&model, &QAbstractItemModel::rowsInserted);
-    model.jobTracker().jobCreated(QStringLiteral("session1"), jobName, QString(), QStringLiteral("type1"), QStringLiteral("debugStr1"));
+    model.jobTracker().jobCreated(u"session1"_s, jobName, QString(), u"type1"_s, QStringLiteral("debugStr1"));
 
     // THEN
     QCOMPARE(model.rowCount(), 1); // 1 session
     const QModelIndex sessionIndex = model.index(0, 0);
-    QCOMPARE(rowSpyToText(rowATBISpy), QStringLiteral("1,1"));
-    QCOMPARE(rowSpyToText(rowInsertedSpy), QStringLiteral("1,1"));
+    QCOMPARE(rowSpyToText(rowATBISpy), u"1,1"_s);
+    QCOMPARE(rowSpyToText(rowInsertedSpy), u"1,1"_s);
     QCOMPARE(model.rowCount(sessionIndex), 2);
 
     // AND WHEN
     model.jobTracker().jobStarted(jobName);
-    model.jobTracker().jobEnded(jobName, QStringLiteral("error"));
+    model.jobTracker().jobEnded(jobName, u"error"_s);
     model.jobTracker().signalUpdates();
 
     // THEN
-    QCOMPARE(model.index(0, JobTrackerModel::ColumnState, sessionIndex).data().toString(), QStringLiteral("Ended"));
-    QCOMPARE(model.index(1, JobTrackerModel::ColumnState, sessionIndex).data().toString(), QStringLiteral("Failed: error"));
+    QCOMPARE(model.index(0, JobTrackerModel::ColumnState, sessionIndex).data().toString(), u"Ended"_s);
+    QCOMPARE(model.index(1, JobTrackerModel::ColumnState, sessionIndex).data().toString(), u"Failed: error"_s);
 }
 
 QTEST_GUILESS_MAIN(JobTrackerModelTest)
